@@ -393,7 +393,7 @@ class RpcService(object):
         if self.stoped:
             return
         self.stoped = True
-        self._recv_task.kill(block=True)
+        self._recv_task.kill(block=0)
         self._recv_task = None
         self.svr.svc_stop(self)
         if 1 and not self.sock_error:
@@ -622,7 +622,7 @@ class RpcService(object):
             else:
                 self.send(RT_RESPONSE | DT_PICKLE, index, pickle_dumps(rs, PICKLE_PROTOCOL))
         except Exception as e:
-            log_except('export(%s).%s(%s)', obj_id, name, argkw)
+            log_except('export(%s).%s(%s)', obj_id, name, repr(argkw))
             if dtype & ST_NO_RESULT or self.svr.stoped:
                 return
             self.send(RT_EXCEPTION, index, pickle_dumps(e, PICKLE_PROTOCOL))
@@ -782,6 +782,8 @@ class RpcClient(RpcBase):
     def svc_stop(self, service):
         if service == self.svc:
             self.stop()
+        else:
+            raise ValueError
 
     def execute(self, func, args, kw, **others):
         return self.svc.call(0, 'execute', (func, args, kw),
@@ -886,6 +888,11 @@ class RpcProxy(object):
     def __getstate__(self):
         return None
 
+    def __call__(self, *args, **kw):
+        no_result, timeout, pickle, proxy = parse_kw(kw, self.timeout)
+        return self._svc.call(self._id, '__call__', args, kw,
+            no_result=no_result, timeout=timeout, pickle=pickle, proxy=proxy)
+
     def __getattr__(self, attribute):
         def _func(*args, **kw):
             no_result, timeout, pickle, proxy = parse_kw(kw, self.timeout)
